@@ -12,7 +12,7 @@
  *
  *  This file is part of AutoOpts, a companion to AutoGen.
  *  AutoOpts is free software.
- *  AutoOpts is Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
+ *  AutoOpts is Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
  *
  *  AutoOpts is available under any one of two licenses.  The license
  *  in use must be one of these two and the choice is under the control
@@ -74,7 +74,7 @@ optionAlias(tOptions * opts, tOptDesc * old_od, unsigned int alias)
     new_od = opts->pOptDesc + alias;
     if ((unsigned)opts->optCt <= alias) {
         fputs(zbad_alias_id, stderr);
-        exit(EXIT_FAILURE);
+        option_exits(EXIT_FAILURE);
     }
 
     /*
