@@ -1,8 +1,7 @@
 /*
    Handle so called 'shell archives'.
 
-   Copyright (C) 1994-2013
-      Free Software Foundation, Inc.
+   Copyright (C) 1994-2014      Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,6 +27,7 @@
 #include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdnoreturn.h>
 #include <string.h>
 #include <sys/utsname.h>
 #include <sys/wait.h>
@@ -37,7 +37,6 @@
 #include "base64.h"
 #include "dirname.h"
 #include "error.h"
-#include "gettext.h"
 #include "idcache.h"
 #include "inttostr.h"
 #include "locale.h"
